@@ -1,13 +1,14 @@
 from time import time
 
+import requests
 from requests import Response
-from typing import Union, List, Tuple, Dict
+from typing import Union, List, Tuple, Dict, Optional
 
 from .stub import StubMixin
 from ..structs import Method, PostLocation
 from .structs.post import PostFeed, PostStory, Comment, UpdateCaption, Save, Like, Unlike, Device, RetrieveByUser, \
     Location, RetrieveByTag, RetrieveLikers, RetrieveCommenters, UserTags, PostNull, RetrieveComments, RetrieveById ,\
-    Archive, Unarchive
+    Archive, Unarchive, RetrieveStory
 
 from ..exceptions import BadResponse
 
@@ -39,8 +40,7 @@ class PostMixin(StubMixin):
     def post_unarchive(self, obj: Unarchive) -> Response:
         return self._post_act(obj)
 
-
-    def post_post(self, obj: Union[PostStory, PostFeed, PostNull], quality: int = None) -> Response:
+    def post_post(self, obj: Union[PostStory, PostFeed, PostNull], quality: Optional[int] = None) -> Response:
         """Uploads a new picture/video to your Instagram account.
         Parameters
         ----------
@@ -72,8 +72,7 @@ class PostMixin(StubMixin):
         url = f'media/{obj.media_id}/info/'
         return self._request(url, Method.GET)
 
-
-    def post_retrieve_by_user(self, obj: RetrieveByUser) -> (RetrieveByUser, Union[dict, bool]):
+    def post_retrieve_by_user(self, obj: RetrieveByUser) -> Tuple[RetrieveByUser, Union[dict, bool]]:
         """Retrieves 12 posts of the user at a time. If there was a response / if there were any more posts
         available, the response can be found in original_requests/post.json:4
 
@@ -92,11 +91,19 @@ class PostMixin(StubMixin):
         resp = self._request(f'feed/user/{obj.user_id}/', Method.GET, query=as_dict)
         resp_as_json = self._json_loads(resp.text)
 
+        # pyre-ignore[16]
         obj.max_id = resp_as_json.get('next_max_id')
         obj.page += 1
+        # pyre-ignore[6]
         return obj, resp_as_json['items']
 
-    def post_retrieve_by_tag(self, obj: RetrieveByTag) -> (RetrieveByTag, Union[dict, bool]):
+    def post_retrieve_story(self, obj: RetrieveStory) -> requests.Response:
+        qp = {
+            'supported_capabilities_new': obj.capabilities_string
+        }
+        return self._request(f'feed/user/{obj.user_id}/story/', Method.GET, qp)
+
+    def post_retrieve_by_tag(self, obj: RetrieveByTag) -> Tuple[RetrieveByTag, Union[dict, bool]]:
         as_dict = obj.to_dict()
 
         if obj.page > 0 and obj.max_id is None:
@@ -107,28 +114,31 @@ class PostMixin(StubMixin):
         resp = self._request(f'feed/tag/{obj.tag_name}/', Method.GET, query=as_dict)
         resp_as_json = self._json_loads(resp.text)
 
+        # pyre-ignore[16]
         obj.max_id = resp_as_json.get('next_max_id')
         obj.page += 1
+        # pyre-ignore[6]
         return obj, resp_as_json['items']
 
-    def post_get_likers(self, obj: RetrieveLikers) -> [any]:
+    def post_get_likers(self, obj: RetrieveLikers) -> List[Dict]:
         """Retrieve all likers of specific media_id"""
         endpoint = 'media/{media_id}/likers'.format(media_id=obj.media_id)
         resp = self._request(endpoint=endpoint, method=Method.GET)
+        # pyre-ignore[6]
         users_as_json = self._json_loads(resp.text)['users']
         return users_as_json
 
-    def post_get_commenters(self, obj: RetrieveCommenters) -> [any]:
+    def post_get_commenters(self, obj: RetrieveCommenters) -> List[Dict]:
         endpoint = 'media/{media_id}/comments'.format(media_id=obj.media_id)
         resp = self._request(endpoint=endpoint, method=Method.GET)
+        # pyre-ignore[6]
         users_as_json = [c['user'] for c in self._json_loads(resp.text)['comments']]
         return users_as_json
 
-    def post_get_comments(self, obj: RetrieveComments):
+    def post_get_comments(self, obj: RetrieveComments) -> Response:
         endpoint = 'media/{media_id}/comments'.format(media_id=obj.media_id)
         resp = self._request(endpoint=endpoint, method=Method.GET)
-        breakpoint()
-
+        return resp
 
     def post_carousel(self, posts: List[PostFeed], caption: str, quality: int) -> Dict[str, Response]:
         upload_id = str(time()).replace('.', '')
@@ -154,11 +164,15 @@ class PostMixin(StubMixin):
                 "timezone_offset": post.timezone_offset,
                 "source_type": str(post.source_type),
                 "scene_type": None,
+                # pyre-ignore[6]
                 "edits": self._json_dumps(post.to_dict()['edits']),
+                # pyre-ignore[6]
                 "extra": self._json_dumps(post.to_dict()['extra']),
+                # pyre-ignore[6]
                 "device": self._json_dumps(post.to_dict()['device'])
             })
-            self._add_user_tags(data, post.user_tags is hasattr(post, 'user_tags'))
+            if hasattr(post, 'user_tags'):
+                self._add_user_tags(data, post.user_tags)
 
         headers = {
             'retry_context': self._json_dumps({"num_reupload": 0, "num_step_auto_retry": 0, "num_step_manual_retry": 0})
@@ -171,13 +185,13 @@ class PostMixin(StubMixin):
         responses['configure_sidecar'] = self._request('media/configure_sidecar/', Method.POST, body=data, headers=headers, sign_request=True)
         return responses
 
-    def _add_user_tags(self, data, user_tags: UserTags):
+    def _add_user_tags(self, data, user_tags: Optional[UserTags]):
         if user_tags is None:
             return
-        user_tags = user_tags.to_dict()
-        for i, user_tag in enumerate(user_tags['in']):
-            user_tags['in'][i] = user_tag.to_dict()
-        data['children_metadata'][-1]['usertags'] = self._json_dumps(user_tags)
+        tags = user_tags.to_dict()
+        for i, user_tag in enumerate(tags['in']):
+            tags['in'][i] = user_tag.to_dict()
+        data['children_metadata'][-1]['usertags'] = self._json_dumps(tags)
 
     def _request_fb_places_id(self, obj: Location) -> str:
         if obj.lat is None or obj.lng is None:
@@ -193,13 +207,16 @@ class PostMixin(StubMixin):
                 "longitude": obj.lng,
             }
             if obj.name:
+                # pyre-ignore[6]
                 query['search_query'] = obj.name
             resp = self._request("location_search", Method.GET, query=query)
 
         as_json = self._json_loads(resp.text)
+        # pyre-ignore[6]
         if as_json['status'] != 'ok':
             raise BadResponse
 
+        # pyre-ignore[6]
         return str(as_json['venues'][0]['external_id'])
 
     def _upload_image(self, obj: Union[PostStory, PostFeed], quality: int, is_sidecar: bool = False) -> Tuple[Response, dict]:
@@ -220,12 +237,15 @@ class PostMixin(StubMixin):
             'creation_logger_session_id': self.state.session_id
         }
 
-        path = as_dict.pop('image_path')
+        path = obj.image_path
+        as_dict.pop('image_path')
+        # pyre-ignore[16] we check if the object has a location attribute.
         if hasattr(obj, 'location') and obj.location is not None:
             if not obj.location.facebook_places_id:
                 obj.location.facebook_places_id = self._request_fb_places_id(obj.location)
             as_dict['location'] = self._json_dumps(obj.location.__dict__)
 
+        # pyre-ignore[16] we check if the object has a usertags attribute.
         if hasattr(obj, 'usertags') and obj.user_tags is not None:
             data = obj.user_tags.to_dict()
             for i, usertag in enumerate(data['in']):
