@@ -3,16 +3,16 @@ import time
 
 
 class Username(cmmn.Base):
-    timezone_offset: int
+    timezone_offset: str = ''
     q: str
     count: int
 
     def __init__(self, q: str, count: int, *args, **kwargs):
         self.q = q
         self.count = count
-        self.timezone_offset = str(time.localtime().tm_gmtoff)
         super().__init__(*args, **kwargs)
 
+
 class Tag(cmmn.Base):
     q: str
     count: int
